#ifndef NT2_INCLUDE_CONSTANTS_TWELVE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TWELVE_HPP_INCLUDED

#include <nt2/constant/include/constants/twelve.hpp>

#endif
